@@ -70,7 +70,7 @@ void print_err( int err, char *func, int arg, int type )
    fprintf( stderr, error_messages[ err ], func, arg, ptr );
 }
 
-void *memory( int size )
+void *memory( unsigned long int size )
 {
    void *ptr;
 
@@ -86,7 +86,7 @@ void *memory( int size )
    return ptr;
 }
 
-char *str_dup( char *str, int len )
+char *str_dup( char *str, unsigned long int len )
 {
    char *ptr;
 
@@ -164,27 +164,29 @@ struct hash_elt *make_hash_elt()
    return hash_elt_pool_ptr++;
 }
 
-unsigned int hash_key( char *name, unsigned int len )
+unsigned long int hash_key( char *name, unsigned long int len )
 {
-   unsigned int i, key;
+   unsigned long int i, key;
    char *nptr;
 
-   if ( len > INT_MAX )
+   if ( len > LONG_MAX )
    {
       fprintf( stderr, "objects cannot have print syntax longer than "
-                       "(maxidx): %d.\n", INT_MAX );
+                       "(maxidx): %lu.\n", LONG_MAX );
       exit( 1 );
    }
 
-   for( i = 0, key = 2166136261, nptr = name; i < len; ++nptr, ++i )
+   key = 2166136261;
+
+   for( i = 0, nptr = name; i < len; ++nptr, ++i )
       key = ( key * 16777619 ) ^ *nptr;
 
    return key;
 }
 
-int insert_elt( struct hash_elt **hash, struct atom *atom, struct object *object, int size )
+int insert_elt( struct hash_elt **hash, struct atom *atom, struct object *object, unsigned long int size )
 {
-   unsigned int orig, key;
+   unsigned long int orig, key;
    struct hash_elt *ptr = NULL, *ptr2 = NULL;
    int found = 0;
 
@@ -226,9 +228,9 @@ int insert_elt( struct hash_elt **hash, struct atom *atom, struct object *object
    return found;
 }
 
-void insert_elt_int( struct hash_elt **hash, struct atom *atom, int elt )
+void insert_elt_int( struct hash_elt **hash, struct atom *atom, long int elt )
 {
-   unsigned int orig, key;
+   unsigned long int orig, key;
    struct hash_elt *ptr = NULL, *ptr2 = NULL;
 
    orig = hash_key( atom->syntax, atom->len );
@@ -264,9 +266,9 @@ void insert_elt_int( struct hash_elt **hash, struct atom *atom, int elt )
    ptr->key = atom;
 }
 
-void *lookup_elt( struct hash_elt **hash, struct atom *atom, int size )
+void *lookup_elt( struct hash_elt **hash, struct atom *atom, unsigned long int size )
 {
-   unsigned int key;
+   unsigned long int key;
    struct hash_elt *ptr;
 
    key = hash_key( atom->syntax, atom->len );
@@ -291,7 +293,7 @@ void *lookup_elt( struct hash_elt **hash, struct atom *atom, int size )
 
 int lookup_elt_int( struct hash_elt **hash, struct atom *atom )
 {
-   unsigned int key;
+   unsigned long int key;
    struct hash_elt *ptr;
 
    key = hash_key( atom->syntax, atom->len );
@@ -314,9 +316,9 @@ int lookup_elt_int( struct hash_elt **hash, struct atom *atom )
    return 0;
 }
 
-int remove_elt( struct hash_elt **hash, struct atom *atom, int size )
+int remove_elt( struct hash_elt **hash, struct atom *atom, unsigned long int size )
 {
-   unsigned int key;
+   unsigned long int key;
    struct hash_elt *ptr, *ptr2;
 
    key = hash_key( atom->syntax, atom->len );
@@ -352,9 +354,9 @@ int remove_elt( struct hash_elt **hash, struct atom *atom, int size )
    return 1;
 }
 
-void remove_id( char *name, unsigned int len, int id )
+void remove_id( char *name, unsigned long int len, int id )
 {
-   unsigned int key;
+   unsigned long int key;
    struct hash_elt *ptr, *ptr2;
 
    key = hash_key( name, len );
@@ -395,16 +397,16 @@ void remove_id( char *name, unsigned int len, int id )
 void resize_syntax()
 {
    struct hash_elt **new, **old, **ptr, *ptr2, *ptr3, *nptr, *nptr2;
-   int size, i, old_size;
-   unsigned int idx;
+   unsigned long size, i, old_size;
+   unsigned long int idx;
 
-   if ( syntax_size * HASH_RESIZE < syntax_size )
+   if ( syntax_size * HASH_RESIZE > ULONG_MAX )
       return;
 
    size = syntax_size * HASH_RESIZE;
 
 #ifdef DEBUG
-   fprintf( stderr, "[resizing syntax table: items: %d, old size: %d...", syntax_items, syntax_size );
+   fprintf( stderr, "[resizing syntax table: items: %lu, old size: %lu...", syntax_items, syntax_size );
 #endif
 
    new = memory( size * sizeof( struct hash_elt * ));
@@ -447,11 +449,11 @@ void resize_syntax()
    free( old );
 
 #ifdef DEBUG
-   fprintf( stderr, "new size: %d]\n", syntax_size );
+   fprintf( stderr, "new size: %lu]\n", syntax_size );
 #endif
 }
 
-struct atom *get_id( char *name, int unsigned len, int duplicate )
+struct atom *get_id( char *name, unsigned long int len, int duplicate )
 {
    unsigned int orig, key;
    struct atom *atom;
@@ -537,7 +539,7 @@ struct atom *get_id( char *name, int unsigned len, int duplicate )
    return atom;
 }
 
-void hash_free( struct hash_elt **hash, int size )
+void hash_free( struct hash_elt **hash, unsigned long int size )
 {
    int i;
    struct hash_elt **ptr, *ptr2, *ptr3;
@@ -1184,7 +1186,7 @@ void stack_push( struct stack *a, void *o )
    ++a->used;
 }
 
-void stack_truncate( struct stack *a, int i )
+void stack_truncate( struct stack *a, long int i )
 {
    while( i-- )
       STACK_POP( a );
@@ -1603,7 +1605,7 @@ int process_token( int type, int depth )
    if ( type == TOK_FIXNUM )
    {
       setnumber( ptr->flags );
-      ptr->data.number = atoi( token->str );
+      ptr->data.number = strtol( token->str, NULL, 10 );
    }
    else
    {
@@ -1682,7 +1684,7 @@ void do_printing( struct object *ptr, int recursive )
          fputc( ')', stdout );
       }
       else if ( numberp( ptr->flags ))
-         printf( "%i", ptr->data.number );
+         printf( "%li", ptr->data.number );
       else
       {
          fwrite( ptr->data.atom->syntax, ptr->data.atom->len, 1, stdout );
