@@ -183,13 +183,13 @@ char **first_arg, **last_arg, **arg_ptr;
 char *syslog_name = NULL;
 
 union stack_u {
-   int integer;
+   long int integer;
    void *ptr;
 };
 
 struct stack
 {
-   int free, used;
+   long int free, used;
    union stack_u *top, *values;
 };
 
@@ -197,20 +197,20 @@ struct hash_elt
 {
    union stack_u element;
    struct hash_elt *next;
-   unsigned int hash_key;
+   unsigned long int hash_key;
    struct atom *key;
 };
 
 struct table
 {
    struct hash_elt **hash;
-   int size, items, resize;
+   unsigned long int size, items, resize;
 };
-
+	
 struct lstring
 {
    char *string;
-   unsigned int length;
+   unsigned long int length;
 };
 
 struct object
@@ -218,7 +218,7 @@ struct object
    int flags;
 
    union {
-      int number;
+      long int number;
       struct atom *atom;
       struct object *head;
    } data;
@@ -229,7 +229,7 @@ struct object
 struct atom
 {
    char *syntax;
-   unsigned int len;
+   unsigned long int len;
    int id;
 
    union {
@@ -278,7 +278,7 @@ void set_sigalrm_intr();
 void set_sigterm_intr();
 void set_sigwinch_intr();
 
-unsigned int hash_key( char *, unsigned int );
+unsigned long int hash_key( char *, unsigned long int );
 int pipe_open( char *, char *, int, int, int * );
 void print_err( int, char *, int, int );
 int evaluate_body( struct object *, int * );
@@ -306,7 +306,7 @@ int history_ptr;
 
 struct hash_elt **env;
 struct hash_elt **syntax;
-int syntax_size, syntax_resize, syntax_items;
+unsigned long int syntax_size, syntax_resize, syntax_items;
 
 struct object *local_env = NULL;
 struct closure *current_closure = NULL;
@@ -374,9 +374,9 @@ struct hash_elt *make_hash_elt();
 
 struct closure *make_closure();
 int create_closure( struct object *, int );
-struct atom *get_id( char *, unsigned int, int );
+struct atom *get_id( char *, unsigned long int, int );
 
-void *memory( int );
+void *memory( unsigned long int );
 void free_executables();
 struct object *duplicate_object( struct object * );
 
@@ -407,20 +407,20 @@ int getline_from_file( char *, int );
 
 struct stack *make_stack();
 void stack_push( struct stack *, void * );
-void stack_push_int( struct stack *, int );
+void stack_push_int( struct stack *, long int );
 struct object *stack_pop( struct stack * );
-int stack_pop_int( struct stack * );
-void stack_truncate( struct stack *, int );
+long int stack_pop_int( struct stack * );
+void stack_truncate( struct stack *, long int );
 void stack_free( struct stack * );
 
 void do_printing( struct object *ptr, int recursive );
 
-int insert_elt( struct hash_elt **, struct atom *, struct object*, int );
-void insert_elt_int( struct hash_elt **, struct atom *, int );
-int remove_elt( struct hash_elt **, struct atom *, int );
-void *lookup_elt( struct hash_elt **, struct atom *, int );
+int insert_elt( struct hash_elt **, struct atom *, struct object*, unsigned long int );
+void insert_elt_int( struct hash_elt **, struct atom *, long int );
+int remove_elt( struct hash_elt **, struct atom *, unsigned long int );
+void *lookup_elt( struct hash_elt **, struct atom *, unsigned long int );
 int lookup_elt_int( struct hash_elt **, struct atom * );
-void hash_free( struct hash_elt **, int );
+void hash_free( struct hash_elt **, unsigned long int );
 
 struct object *lookup_local( int id );
 
@@ -429,10 +429,10 @@ struct object *lookup_local( int id );
 #define remove_binding(n) remove_elt( env, n, HASH_SIZE )
 
 struct object *make_atom_from_act_record( struct stack * );
-struct object *make_atom_from_number( int );
+struct object *make_atom_from_number( long int );
 struct object *make_atom_from_closure( struct closure *, int );
-struct object *make_atom_from_string( char *, unsigned int );
-struct object *make_atom_directly_from_string( char *, unsigned int );
+struct object *make_atom_from_string( char *, unsigned long int );
+struct object *make_atom_directly_from_string( char *, unsigned long int );
 
 struct string *make_string();
 void string_free( struct string * );
@@ -443,7 +443,7 @@ void string_truncate( struct string * );
 void string_assign( struct string *, char *, int );
 void string_erase( struct string *, int );
 
-char *str_dup( char *, int );
+char *str_dup( char *, unsigned long int );
 
 FUNC( file2string );
 FUNC( progn );
@@ -1091,7 +1091,6 @@ int ( *intrinsics[] )( char *, struct object * ) =
    do_notbusy,
    do_busyp,
    do_sleep,
-   do_unsigned,
    do_get_scgi_header,
    do_form_decode,
    do_form_encode,
@@ -1419,7 +1418,6 @@ char *intrinsic_syntax[] =
    "<NOTBUSY>",             "notbusy",
    "<BUSP>",                "busyp",
    "<SLEEP>",               "sleep",
-   "<UNSIGNED>",            "unsigned",
    "<GET_SCGI_HEADER>",     "get_scgi_header",
    "<FORM_DECODE>",         "form_decode",
    "<FORM_ENCODE>",         "form_encode",
